summaryrefslogtreecommitdiffstats
path: root/src/main.cpp
diff options
context:
space:
mode:
authorNicolas Dufour <nicoduf@yahoo.fr>2012-07-16 19:29:46 +0000
committerJazzyNico <nicoduf@yahoo.fr>2012-07-16 19:29:46 +0000
commit93463310815d358c470898aba487ac8392aec027 (patch)
tree438824255d13d9239287a98ee17d3305ee9a150a /src/main.cpp
parentFix for 167846 : Focus issue between spinbuttons when using Tab (diff)
downloadinkscape-93463310815d358c470898aba487ac8392aec027.tar.gz
inkscape-93463310815d358c470898aba487ac8392aec027.zip
Fix for Bug #425202 (Script messages not translated).
(bzr r11551)
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/main.cpp b/src/main.cpp
index 74083e776..e3862589d 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -474,7 +474,8 @@ gchar * blankParam = g_strdup("");
#ifdef WIN32
/**
* Set up the PATH and PYTHONPATH environment variables on Windows
* @param exe Inkscape executable directory in UTF-8
*/
static void _win32_set_inkscape_env(gchar const *exe)
@@ -525,7 +526,11 @@ static void _win32_set_inkscape_env(gchar const *exe)
} else {
printf("python not found\n\n");
}*/
-
+
+ // INKSCAPE_LOCALEDIR is needed by Python/Gettext
+ gchar *localepath = g_build_filename(exe, PACKAGE_LOCALE_DIR, NULL);
+ g_setenv("INKSCAPE_LOCALEDIR", localepath, TRUE);
+
g_free(python);
g_free(scripts);
g_free(perl);
@@ -538,6 +543,8 @@ static void _win32_set_inkscape_env(gchar const *exe)
g_free(new_path);
g_free(new_pythonpath);
+
+ g_free(localepath);
}
#endif
@@ -474,7 +474,8 @@ gchar * blankParam = g_strdup("");
#ifdef WIN32
/**
- * Set up the PATH and PYTHONPATH environment variables on Windows
+ * Set up the PATH, INKSCAPE_LOCALEDIR and PYTHONPATH environment
+ * variables on Windows
* @param exe Inkscape executable directory in UTF-8
*/